==> gorilla-notebook-0.4.0.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.worksheet.code_segment_view.js <==
goog.provide('pinkgorilla.worksheet.code_segment_view');
goog.require('cljs.core');
goog.require('reagent.core');
goog.require('re_frame.core');
goog.require('pinkgorilla.output.core');
goog.require('pinkgorilla.worksheet.helper');
pinkgorilla.worksheet.code_segment_view.code_segment_view = (function pinkgorilla$worksheet$code_segment_view$code_segment_view(seg_data){
var seg_id = new cljs.core.Keyword(null,"id","id",-1388402092).cljs$core$IFn$_invoke$arity$1(seg_data);
var segment = (function (){var G__29026 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"segment-query","segment-query",-1716724073),seg_id], null);
return (re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1(G__29026) : re_frame.core.subscribe.call(null,G__29026));
})();
var footer_comp = cljs.core.with_meta(new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div.segment-footer","div.segment-footer",-2057531745)], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"segment-footer","segment-footer",-592886034)], null));
return reagent.core.create_class(new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"component-did-mount","component-did-mount",-1126910518),(function (this$){
return pinkgorilla.worksheet.helper.colorize_cm_BANG_(this$);
}),new cljs.core.Keyword(null,"display-name","display-name",694513143),"code-segment-view",new cljs.core.Keyword(null,"reagent-render","reagent-render",-985383853),(function (seg_data__$1){
var main_component = cljs.core.with_meta(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div.segment-main","div.segment-main",-443293511),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"pre","pre",2118456869),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"class","class",-2030961996),"static-code clojure"], null),cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(segment),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"content","content",15833224),new cljs.core.Keyword(null,"value","value",305978217)], null))], null)], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"segment-main","segment-main",943667053)], null));
var error_comp = (function (){var temp__5733__auto__ = new cljs.core.Keyword(null,"error-text","error-text",2021893718).cljs$core$IFn$_invoke$arity$1(cljs.core.deref(segment));
if(cljs.core.truth_(temp__5733__auto__)){
var err_text = temp__5733__auto__;
return cljs.core.with_meta(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [pinkgorilla.worksheet.helper.error_text,err_text], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"error-text","error-text",2021893718)], null));
} else {
return null;
}
})();
var ex_comp = (function (){var temp__5733__auto__ = new cljs.core.Keyword(null,"exception","exception",-335277064).cljs$core$IFn$_invoke$arity$1(cljs.core.deref(segment));
if(cljs.core.truth_(temp__5733__auto__)){
var ex = temp__5733__auto__;
return cljs.core.with_meta(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [pinkgorilla.worksheet.helper.exception,ex], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"exception","exception",-335277064)], null));
} else {
return null;
}
})();
var console_comp = (function (){var temp__5733__auto__ = cljs.core.not_empty(new cljs.core.Keyword(null,"console-response","console-response",81719661).cljs$core$IFn$_invoke$arity$1(cljs.core.deref(segment)));
if(cljs.core.truth_(temp__5733__auto__)){
var cons_text = temp__5733__auto__;
return cljs.core.with_meta(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [pinkgorilla.worksheet.helper.console_text,cons_text], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"console-response","console-response",81719661)], null));
} else {
return null;
}
})();
var output_comp = (function (){var temp__5733__auto__ = cljs.core.not_empty(new cljs.core.Keyword(null,"value-response","value-response",-1249272942).cljs$core$IFn$_invoke$arity$1(cljs.core.deref(segment)));
if(cljs.core.truth_(temp__5733__auto__)){
var value_output = temp__5733__auto__;
var output_value = pinkgorilla.output.core.output_fn(value_output);
return cljs.core.with_meta(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div.output>pre","div.output>pre",-1192646501),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [output_value,value_output,seg_id], null)], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"value-response","value-response",-1249272942)], null));
} else {
return null;
}
})();
var div_kw = cljs.core.keyword.cljs$core$IFn$_invoke$arity$1(["div#",cljs.core.name(seg_id)].join(''));
var other_children = new cljs.core.PersistentVector(null, 6, 5, cljs.core.PersistentVector.EMPTY_NODE, [main_component,error_comp,ex_comp,console_comp,output_comp,footer_comp], null);
return cljs.core.apply.cljs$core$IFn$_invoke$arity$3(cljs.core.conj,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [div_kw,new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"class","class",-2030961996),"segment code"], null)], null),cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.some_QMARK_,other_children));
})], null));
});

//# sourceMappingURL=pinkgorilla.worksheet.code_segment_view.js.map

==> gorilla-notebook-0.4.3.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.worksheet.code_segment_view.js <==
goog.provide('pinkgorilla.worksheet.code_segment_view');
goog.require('cljs.core');
goog.require('reagent.core');
goog.require('re_frame.core');
goog.require('pinkgorilla.output.core');
goog.require('pinkgorilla.worksheet.helper');
pinkgorilla.worksheet.code_segment_view.code_segment_view = (function pinkgorilla$worksheet$code_segment_view$code_segment_view(seg_data){
var seg_id = new cljs.core.Keyword(null,"id","id",-1388402092).cljs$core$IFn$_invoke$arity$1(seg_data);
var segment = (function (){var G__55419 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"segment-query","segment-query",-1716724073),seg_id], null);
return (re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.subscribe.cljs$core$IFn$_invoke$arity$1(G__55419) : re_frame.core.subscribe.call(null,G__55419));
})();
var footer_comp = cljs.core.with_meta(new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div.segment-footer","div.segment-footer",-2057531745)], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"segment-footer","segment-footer",-592886034)], null));
return reagent.core.create_class(new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"component-did-mount","component-did-mount",-1126910518),(function (this$){
return pinkgorilla.worksheet.helper.colorize_cm_BANG_(this$);
}),new cljs.core.Keyword(null,"display-name","display-name",694513143),"code-segment-view",new cljs.core.Keyword(null,"reagent-render","reagent-render",-985383853),(function (_){
var main_component = cljs.core.with_meta(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div.segment-main","div.segment-main",-443293511),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"pre","pre",2118456869),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"class","class",-2030961996),"static-code clojure"], null),cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(segment),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"content","content",15833224),new cljs.core.Keyword(null,"value","value",305978217)], null))], null)], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"segment-main","segment-main",943667053)], null));
var error_comp = (function (){var temp__5733__auto__ = new cljs.core.Keyword(null,"error-text","error-text",2021893718).cljs$core$IFn$_invoke$arity$1(cljs.core.deref(segment));
if(cljs.core.truth_(temp__5733__auto__)){
var err_text = temp__5733__auto__;
return cljs.core.with_meta(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [pinkgorilla.worksheet.helper.error_text,err_text], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"error-text","error-text",2021893718)], null));
} else {
return null;
}
})();
var ex_comp = (function (){var temp__5733__auto__ = new cljs.core.Keyword(null,"exception","exception",-335277064).cljs$core$IFn$_invoke$arity$1(cljs.core.deref(segment));
if(cljs.core.truth_(temp__5733__auto__)){
var ex = temp__5733__auto__;
return cljs.core.with_meta(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [pinkgorilla.worksheet.helper.exception,ex], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"exception","exception",-335277064)], null));
} else {
return null;
}
})();
var console_comp = (function (){var temp__5733__auto__ = cljs.core.not_empty(new cljs.core.Keyword(null,"console-response","console-response",81719661).cljs$core$IFn$_invoke$arity$1(cljs.core.deref(segment)));
if(cljs.core.truth_(temp__5733__auto__)){
var cons_text = temp__5733__auto__;
return cljs.core.with_meta(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [pinkgorilla.worksheet.helper.console_text,cons_text], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"console-response","console-response",81719661)], null));
} else {
return null;
}
})();
var output_comp = (function (){var temp__5733__auto__ = cljs.core.not_empty(new cljs.core.Keyword(null,"value-response","value-response",-1249272942).cljs$core$IFn$_invoke$arity$1(cljs.core.deref(segment)));
if(cljs.core.truth_(temp__5733__auto__)){
var value_output = temp__5733__auto__;
var output_value = pinkgorilla.output.core.output_fn(value_output);
return cljs.core.with_meta(new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div.output>pre","div.output>pre",-1192646501),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [output_value,value_output,seg_id], null)], null),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"key","key",-1516042587),new cljs.core.Keyword(null,"value-response","value-response",-1249272942)], null));
} else {
return null;
}
})();
var div_kw = cljs.core.keyword.cljs$core$IFn$_invoke$arity$1(["div#",cljs.core.name(seg_id)].join(''));
var other_children = new cljs.core.PersistentVector(null, 6, 5, cljs.core.PersistentVector.EMPTY_NODE, [main_component,error_comp,ex_comp,console_comp,output_comp,footer_comp], null);
return cljs.core.apply.cljs$core$IFn$_invoke$arity$3(cljs.core.conj,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [div_kw,new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"class","class",-2030961996),"segment code"], null)], null),cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.some_QMARK_,other_children));
})], null));
});

//# sourceMappingURL=pinkgorilla.worksheet.code_segment_view.js.map
